# NOMAD CAMELS toolbox

This package provides easy access to data generated with [NOMAD CAMELS](https://github.com/FAU-LAP/NOMAD-CAMELS).

Simplify your data evaluation with the NOMAD CAMELS toolbox!


# Changelog

### 0.2.2
Fixes:
- fixed import problems

### 0.2.1
Features:
- custom plots in qt-viewer

Fixes:
- installation fixed
- qt viewer more stable

## 0.2.0
Features:
- Recreating plots from CAMELS with a single function
- UI tool to view data in a simplified way

### 0.1.2
Fixes:
- fixed returning of dataframes for different shapes of the data
